@@ -1,10 +1,5 @@
 package CPAN::Repository;
-BEGIN {
-  $CPAN::Repository::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $CPAN::Repository::VERSION = '0.008';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: API to access a directory which can be served as CPAN repository
 
 use Moo;
@@ -196,8 +191,8 @@ sub mkdir {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -206,7 +201,7 @@ CPAN::Repository - API to access a directory which can be served as CPAN reposit
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -226,10 +221,10 @@ version 0.008
   
   my %modules = %{$repo->modules};
   
-  my $fullpath_to_authordir = $self->authordir('SOMEONE');
+  my $fullpath_to_authordir = $repo->authordir('SOMEONE');
  
-  my $packages = $self->packages; # gives back a CPAN::Repository::Packages
-  my $mailrc = $self->mailrc; # gives back a CPAN::Repository::Mailrc
+  my $packages = $repo->packages; # gives back a CPAN::Repository::Packages
+  my $mailrc = $repo->mailrc; # gives back a CPAN::Repository::Mailrc
 
 =head1 DESCRIPTION
 
@@ -271,4 +266,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
