@@ -1,12 +1,7 @@
 package CPAN::Repository::Mailrc;
-BEGIN {
-  $CPAN::Repository::Mailrc::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $CPAN::Repository::Mailrc::VERSION = '0.008';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: 01mailrc
-
+$CPAN::Repository::Mailrc::VERSION = '0.009';
 use Moo;
 
 with qw(
@@ -58,9 +53,8 @@ sub generate_content {
 
 1;
 
-
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -69,7 +63,7 @@ CPAN::Repository::Mailrc - 01mailrc
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -112,4 +106,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
