@@ -1,12 +1,7 @@
 package CPAN::Repository::Packages;
-BEGIN {
-  $CPAN::Repository::Packages::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $CPAN::Repository::Packages::VERSION = '0.008';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: 02packages
-
+$CPAN::Repository::Packages::VERSION = '0.009';
 use Moo;
 
 with qw(
@@ -141,8 +136,8 @@ sub generate_header_line {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -151,7 +146,7 @@ CPAN::Repository::Packages - 02packages
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -197,4 +192,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
