@@ -1,12 +1,7 @@
 package CPAN::Repository::Role::File;
-BEGIN {
-  $CPAN::Repository::Role::File::AUTHORITY = 'cpan:GETTY';
-}
-{
-  $CPAN::Repository::Role::File::VERSION = '0.008';
-}
+our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Role for file functions
-
+$CPAN::Repository::Role::File::VERSION = '0.009';
 use Moo::Role;
 
 use File::Path qw( make_path );
@@ -92,8 +87,8 @@ sub mkdir {
 
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -102,7 +97,7 @@ CPAN::Repository::Role::File - Role for file functions
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =encoding utf8
 
@@ -133,4 +128,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
